@@ -1,4 +1,4 @@
-  #' @include SetInterval_SpecialSet.R ParameterSet.R
+
 #-------------------------------------------------------------
 #  Distribution Documentation
 #-------------------------------------------------------------
@@ -52,11 +52,10 @@ NULL
 #-------------------------------------------------------------
 # Dirichlet Distribution Definition
 #-------------------------------------------------------------
-Dirichlet <- R6::R6Class("Dirichlet", inherit = SDistribution, lock_objects = F)
+Dirichlet <- R6Class("Dirichlet", inherit = SDistribution, lock_objects = F)
 Dirichlet$set("public","name","Dirichlet")
 Dirichlet$set("public","short_name","Diri")
 Dirichlet$set("public","description","Multivariate Normal Probability Distribution.")
-Dirichlet$set("public","package","distr6")
 
 Dirichlet$set("public","mean",function(){
   return(self$getParameterValue("params")/sum(self$getParameterValue("params")))
@@ -149,9 +148,9 @@ Dirichlet$set("public","initialize",function(params = c(1, 1), decorators = NULL
   }
 
   super$initialize(decorators = decorators, pdf = pdf, rand = rand,
-                   support = Interval$new(0,1,type="()",dim = length(params)),
+                   support = setpower(Interval$new(0,1,type="()"), length(params)),
                    symmetric = FALSE,
-                   type = Interval$new(0,1,dim = "K"),
+                   type = setpower(Interval$new(0,1,type="()"), length(params)),
                    valueSupport = "continuous",
                    variateForm = "multivariate")
   invisible(self)
@@ -161,5 +160,5 @@ Dirichlet$set("public","initialize",function(params = c(1, 1), decorators = NULL
                               data.table::data.table(ShortName = "Diri", ClassName = "Dirichlet",
                                                      Type = "[0,1]^K", ValueSupport = "continuous",
                                                      VariateForm = "multivariate",
-                                                     Package = "distr6"))
+                                                     Package = "-"))
 
