@@ -44,21 +44,21 @@ Empirical$set("public","description","Empirical Probability Distribution.")
 
 Empirical$set("public","mode",function(which = "all"){
   if(which == "all")
-    return(modal(unlist(self$support()$elements)))
+    return(modal(unlist(self$support$elements)))
   else
-    return(modal(unlist(self$support()$elements))[which])
+    return(modal(unlist(self$support$elements))[which])
 })
 Empirical$set("public","mean",function(){
-  return(mean(unlist(self$support()$elements)))
+  return(mean(unlist(self$support$elements)))
 })
 Empirical$set("public","variance",function(){
-  return(sum((unlist(self$support()$elements) - self$mean())^2)/private$.total)
+  return(sum((unlist(self$support$elements) - self$mean())^2)/private$.total)
 })
 Empirical$set("public","skewness",function(){
-  return(sum(((unlist(self$support()$elements) - self$mean())/self$stdev())^3)/private$.total)
+  return(sum(((unlist(self$support$elements) - self$mean())/self$stdev())^3)/private$.total)
 })
 Empirical$set("public","kurtosis",function(excess = TRUE){
-  kurt = sum(((unlist(self$support()$elements) - self$mean())/self$stdev())^4)/private$.total
+  kurt = sum(((unlist(self$support$elements) - self$mean())/self$stdev())^4)/private$.total
   if(excess)
     return(kurt - 3)
   else
@@ -142,7 +142,7 @@ Empirical$set("public","initialize",function(samples, decorators = NULL, verbose
   }
 
   rand <- function(n){
-    return(sample(unlist(self$support()$elements), n, TRUE))
+    return(sample(unlist(self$support$elements), n, TRUE))
   }
 
   super$initialize(decorators = decorators, pdf = pdf, cdf = cdf, quantile = quantile, rand = rand,
