@@ -1,4 +1,4 @@
-#' @include SetInterval_SpecialSet.R ParameterSet.R
+
 #-------------------------------------------------------------
 # Exponential Distribution Documentation
 #-------------------------------------------------------------
@@ -45,11 +45,11 @@ NULL
 #-------------------------------------------------------------
 # Exponential Distribution Definition
 #-------------------------------------------------------------
-Exponential <- R6::R6Class("Exponential", inherit = SDistribution, lock_objects = F)
+Exponential <- R6Class("Exponential", inherit = SDistribution, lock_objects = F)
 Exponential$set("public","name","Exponential")
 Exponential$set("public","short_name","Exp")
 Exponential$set("public","description","Exponential Probability Distribution.")
-Exponential$set("public","package","stats")
+Exponential$set("public","packages","stats")
 
 Exponential$set("public","mean",function(){
   self$getParameterValue("scale")
