@@ -1,4 +1,4 @@
-#' @include SetInterval_SpecialSet.R ParameterSet.R
+
 #-------------------------------------------------------------
 # Uniform Distribution Documentation
 #-------------------------------------------------------------
@@ -42,11 +42,11 @@ NULL
 #-------------------------------------------------------------
 # Uniform Distribution Definition
 #-------------------------------------------------------------
-Uniform <- R6::R6Class("Uniform", inherit = SDistribution, lock_objects = F)
+Uniform <- R6Class("Uniform", inherit = SDistribution, lock_objects = F)
 Uniform$set("public","name","Uniform")
 Uniform$set("public","short_name","Unif")
 Uniform$set("public","description","Uniform Probability Distribution.")
-Uniform$set("public","package","stats")
+Uniform$set("public","packages","stats")
 
 
 Uniform$set("public","mean",function(){
