@@ -44,15 +44,9 @@ NULL
 
 #' @name ArrayDistribution
 #' @rdname distr6-deprecated
-#' @section Deprecated Functions:
-#' \tabular{ll}{
-#' \strong{Deprecated} \tab \strong{Replacement} \cr
-#' \code{ArrayDistribution} \tab \code{\link{ProductDistribution}} \cr
-#' }
-#'
 #' @export
 NULL
-ArrayDistribution <- R6::R6Class("ArrayDistribution", inherit = ProductDistribution)
+ArrayDistribution <- R6Class("ArrayDistribution", inherit = ProductDistribution)
 ArrayDistribution$set("public","initialize",function(...){
   .Deprecated("ProductDistribution", "distr6", "The ArrayDistribution wrapper is now deprecated and has
 been merged with the ProductDistribution wrapper.")
