@@ -42,7 +42,7 @@ N$traits
 
 ## -----------------------------------------------------------------------------
 N$valueSupport
-N$skewness
+N$skewnessType
 
 ## -----------------------------------------------------------------------------
 N$pdf(2) # dnorm(2)
