@@ -12,13 +12,13 @@ test_that("parameterisation",{
 })
 
 test_that("properties & traits",{
-  expect_equal(Gumbel$new()$valueSupport(), "continuous")
-  expect_equal(Gumbel$new()$variateForm(), "univariate")
-  expect_equal(Gumbel$new()$symmetry(), "symmetric")
-  expect_equal(Gumbel$new()$sup(), Inf)
-  expect_equal(Gumbel$new()$inf(), -Inf)
-  expect_equal(Gumbel$new()$dmax(), Inf)
-  expect_equal(Gumbel$new()$dmin(), -Inf)
+  expect_equal(Gumbel$new()$valueSupport, "continuous")
+  expect_equal(Gumbel$new()$variateForm, "univariate")
+  expect_equal(Gumbel$new()$symmetry, "symmetric")
+  expect_equal(Gumbel$new()$sup, Inf)
+  expect_equal(Gumbel$new()$inf, -Inf)
+  expect_equal(Gumbel$new()$dmax, Inf)
+  expect_equal(Gumbel$new()$dmin, -Inf)
 })
 
 c = Gumbel$new(location = 0, scale = 1)
