@@ -3,13 +3,13 @@ library(testthat)
 context("Poisson distribution")
 
 test_that("properties & traits",{
-  expect_equal(Poisson$new()$valueSupport(), "discrete")
-  expect_equal(Poisson$new()$variateForm(), "univariate")
-  expect_equal(Poisson$new()$symmetry(), "asymmetric")
-  expect_equal(Poisson$new()$sup(), Inf)
-  expect_equal(Poisson$new()$inf(), 0)
-  expect_equal(Poisson$new()$dmax(),Inf)
-  expect_equal(Poisson$new()$dmin(), 0)
+  expect_equal(Poisson$new()$valueSupport, "discrete")
+  expect_equal(Poisson$new()$variateForm, "univariate")
+  expect_equal(Poisson$new()$symmetry, "asymmetric")
+  expect_equal(Poisson$new()$sup, Inf)
+  expect_equal(Poisson$new()$inf, 0)
+  expect_equal(Poisson$new()$dmax,Inf)
+  expect_equal(Poisson$new()$dmin, 0)
 })
 
 b = Poisson$new()
